Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterEciServiceServer(s grpc.ServiceRegistrar, srv EciServiceServer)
- type BalanceRequest
- func (*BalanceRequest) Descriptor() ([]byte, []int)deprecated
- func (x *BalanceRequest) GetCustomerId() string
- func (x *BalanceRequest) GetUserId() string
- func (*BalanceRequest) ProtoMessage()
- func (x *BalanceRequest) ProtoReflect() protoreflect.Message
- func (x *BalanceRequest) Reset()
- func (x *BalanceRequest) String() string
- type BalanceResponse
- type Container
- func (*Container) Descriptor() ([]byte, []int)deprecated
- func (x *Container) GetCpu() int32
- func (x *Container) GetExitCode() int32
- func (x *Container) GetGpu() int32
- func (x *Container) GetImage() string
- func (x *Container) GetName() string
- func (x *Container) GetRam() int32
- func (x *Container) GetReason() string
- func (x *Container) GetRestart() int32
- func (x *Container) GetStatus() string
- func (*Container) ProtoMessage()
- func (x *Container) ProtoReflect() protoreflect.Message
- func (x *Container) Reset()
- func (x *Container) String() string
- type EciCache
- func (*EciCache) Descriptor() ([]byte, []int)deprecated
- func (x *EciCache) GetErrMessage() string
- func (x *EciCache) GetId() string
- func (x *EciCache) GetProgress() int32
- func (*EciCache) ProtoMessage()
- func (x *EciCache) ProtoReflect() protoreflect.Message
- func (x *EciCache) Reset()
- func (x *EciCache) String() string
- type EciPod
- func (*EciPod) Descriptor() ([]byte, []int)deprecated
- func (x *EciPod) GetContainerGroupName() string
- func (x *EciPod) GetCustomerId() string
- func (x *EciPod) GetPod() *Pod
- func (x *EciPod) GetRuntime() string
- func (x *EciPod) GetSpotPrice() string
- func (x *EciPod) GetSpotStrategy() string
- func (x *EciPod) GetUserId() string
- func (x *EciPod) GetVNodeId() string
- func (*EciPod) ProtoMessage()
- func (x *EciPod) ProtoReflect() protoreflect.Message
- func (x *EciPod) Reset()
- func (x *EciPod) String() string
- type EciServiceClient
- type EciServiceServer
- type EciVNode
- func (*EciVNode) Descriptor() ([]byte, []int)deprecated
- func (x *EciVNode) GetCustomerId() string
- func (x *EciVNode) GetReady() bool
- func (x *EciVNode) GetUserId() string
- func (x *EciVNode) GetVNodeId() string
- func (*EciVNode) ProtoMessage()
- func (x *EciVNode) ProtoReflect() protoreflect.Message
- func (x *EciVNode) Reset()
- func (x *EciVNode) String() string
- type NetworkInfo
- func (*NetworkInfo) Descriptor() ([]byte, []int)deprecated
- func (x *NetworkInfo) GetGateway() string
- func (x *NetworkInfo) GetIp() string
- func (x *NetworkInfo) GetVlan() string
- func (*NetworkInfo) ProtoMessage()
- func (x *NetworkInfo) ProtoReflect() protoreflect.Message
- func (x *NetworkInfo) Reset()
- func (x *NetworkInfo) String() string
- type NotifyCode
- type NotifyRequest
- func (*NotifyRequest) Descriptor() ([]byte, []int)deprecated
- func (x *NotifyRequest) GetCode() NotifyCode
- func (x *NotifyRequest) GetCustomerId() string
- func (x *NotifyRequest) GetId() string
- func (x *NotifyRequest) GetSpotTime() int64
- func (x *NotifyRequest) GetUserId() string
- func (*NotifyRequest) ProtoMessage()
- func (x *NotifyRequest) ProtoReflect() protoreflect.Message
- func (x *NotifyRequest) Reset()
- func (x *NotifyRequest) String() string
- type NotifyResponse
- type Pod
- func (*Pod) Descriptor() ([]byte, []int)deprecated
- func (x *Pod) GetBoot() bool
- func (x *Pod) GetCode() PodStatusCode
- func (x *Pod) GetContainers() []*Container
- func (x *Pod) GetCpu() int32
- func (x *Pod) GetCpuType() string
- func (x *Pod) GetEphemeralStorage() int32
- func (x *Pod) GetFamilyId() string
- func (x *Pod) GetGpu() int32
- func (x *Pod) GetGpuType() string
- func (x *Pod) GetId() string
- func (x *Pod) GetName() string
- func (x *Pod) GetNamespace() string
- func (x *Pod) GetNetwork() *NetworkInfo
- func (x *Pod) GetRam() int32
- func (x *Pod) GetRestartPolicy() string
- func (x *Pod) GetStatus() string
- func (x *Pod) GetUID() string
- func (*Pod) ProtoMessage()
- func (x *Pod) ProtoReflect() protoreflect.Message
- func (x *Pod) Reset()
- func (x *Pod) String() string
- type PodStatusCode
- func (PodStatusCode) Descriptor() protoreflect.EnumDescriptor
- func (x PodStatusCode) Enum() *PodStatusCode
- func (PodStatusCode) EnumDescriptor() ([]byte, []int)deprecated
- func (x PodStatusCode) Number() protoreflect.EnumNumber
- func (x PodStatusCode) String() string
- func (PodStatusCode) Type() protoreflect.EnumType
- type SaveCacheResponse
- func (*SaveCacheResponse) Descriptor() ([]byte, []int)deprecated
- func (x *SaveCacheResponse) GetCode() string
- func (x *SaveCacheResponse) GetMsg() string
- func (*SaveCacheResponse) ProtoMessage()
- func (x *SaveCacheResponse) ProtoReflect() protoreflect.Message
- func (x *SaveCacheResponse) Reset()
- func (x *SaveCacheResponse) String() string
- type SavePodResp
- type SaveVNodeResp
- func (*SaveVNodeResp) Descriptor() ([]byte, []int)deprecated
- func (x *SaveVNodeResp) GetCode() string
- func (x *SaveVNodeResp) GetMsg() string
- func (*SaveVNodeResp) ProtoMessage()
- func (x *SaveVNodeResp) ProtoReflect() protoreflect.Message
- func (x *SaveVNodeResp) Reset()
- func (x *SaveVNodeResp) String() string
- type UnimplementedEciServiceServer
- func (UnimplementedEciServiceServer) HasBalance(context.Context, *BalanceRequest) (*BalanceResponse, error)
- func (UnimplementedEciServiceServer) SaveCaches(context.Context, *EciCache) (*SaveCacheResponse, error)
- func (UnimplementedEciServiceServer) SavePod(context.Context, *EciPod) (*SavePodResp, error)
- func (UnimplementedEciServiceServer) SaveVNode(context.Context, *EciVNode) (*SaveVNodeResp, error)
- func (UnimplementedEciServiceServer) SendUserNotification(context.Context, *NotifyRequest) (*NotifyResponse, error)
- type UnsafeEciServiceServer
Constants ¶
const ( EciService_SavePod_FullMethodName = "/pod.EciService/SavePod" EciService_SaveVNode_FullMethodName = "/pod.EciService/SaveVNode" EciService_SendUserNotification_FullMethodName = "/pod.EciService/SendUserNotification" EciService_HasBalance_FullMethodName = "/pod.EciService/HasBalance" EciService_SaveCaches_FullMethodName = "/pod.EciService/SaveCaches" )
Variables ¶
var ( PodStatusCode_name = map[int32]string{ 0: "StatusDefault", 1: "StatusSpotFailed", 2: "StatusSpotDelayedDelete", } PodStatusCode_value = map[string]int32{ "StatusDefault": 0, "StatusSpotFailed": 1, "StatusSpotDelayedDelete": 2, } )
Enum value maps for PodStatusCode.
var ( NotifyCode_name = map[int32]string{ 0: "SpotFailed", 1: "SpotCancelDelete", } NotifyCode_value = map[string]int32{ "SpotFailed": 0, "SpotCancelDelete": 1, } )
Enum value maps for NotifyCode.
var EciService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "pod.EciService", HandlerType: (*EciServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "SavePod", Handler: _EciService_SavePod_Handler, }, { MethodName: "SaveVNode", Handler: _EciService_SaveVNode_Handler, }, { MethodName: "SendUserNotification", Handler: _EciService_SendUserNotification_Handler, }, { MethodName: "HasBalance", Handler: _EciService_HasBalance_Handler, }, { MethodName: "SaveCaches", Handler: _EciService_SaveCaches_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "pod/v1/pod.proto", }
EciService_ServiceDesc is the grpc.ServiceDesc for EciService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_pod_v1_pod_proto protoreflect.FileDescriptor
Functions ¶
func RegisterEciServiceServer ¶
func RegisterEciServiceServer(s grpc.ServiceRegistrar, srv EciServiceServer)
Types ¶
type BalanceRequest ¶ added in v1.1.69
type BalanceRequest struct {
CustomerId string `protobuf:"bytes,1,opt,name=CustomerId,proto3" json:"CustomerId,omitempty"`
UserId string `protobuf:"bytes,2,opt,name=UserId,proto3" json:"UserId,omitempty"`
// contains filtered or unexported fields
}
func (*BalanceRequest) Descriptor
deprecated
added in
v1.1.69
func (*BalanceRequest) Descriptor() ([]byte, []int)
Deprecated: Use BalanceRequest.ProtoReflect.Descriptor instead.
func (*BalanceRequest) GetCustomerId ¶ added in v1.1.69
func (x *BalanceRequest) GetCustomerId() string
func (*BalanceRequest) GetUserId ¶ added in v1.1.69
func (x *BalanceRequest) GetUserId() string
func (*BalanceRequest) ProtoMessage ¶ added in v1.1.69
func (*BalanceRequest) ProtoMessage()
func (*BalanceRequest) ProtoReflect ¶ added in v1.1.69
func (x *BalanceRequest) ProtoReflect() protoreflect.Message
func (*BalanceRequest) Reset ¶ added in v1.1.69
func (x *BalanceRequest) Reset()
func (*BalanceRequest) String ¶ added in v1.1.69
func (x *BalanceRequest) String() string
type BalanceResponse ¶ added in v1.1.69
type BalanceResponse struct {
Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*BalanceResponse) Descriptor
deprecated
added in
v1.1.69
func (*BalanceResponse) Descriptor() ([]byte, []int)
Deprecated: Use BalanceResponse.ProtoReflect.Descriptor instead.
func (*BalanceResponse) GetResult ¶ added in v1.1.69
func (x *BalanceResponse) GetResult() bool
func (*BalanceResponse) ProtoMessage ¶ added in v1.1.69
func (*BalanceResponse) ProtoMessage()
func (*BalanceResponse) ProtoReflect ¶ added in v1.1.69
func (x *BalanceResponse) ProtoReflect() protoreflect.Message
func (*BalanceResponse) Reset ¶ added in v1.1.69
func (x *BalanceResponse) Reset()
func (*BalanceResponse) String ¶ added in v1.1.69
func (x *BalanceResponse) String() string
type Container ¶ added in v1.1.30
type Container struct {
Name string `protobuf:"bytes,1,opt,name=Name,proto3" json:"Name,omitempty"`
Image string `protobuf:"bytes,2,opt,name=Image,proto3" json:"Image,omitempty"`
Status string `protobuf:"bytes,3,opt,name=Status,proto3" json:"Status,omitempty"`
ExitCode int32 `protobuf:"varint,4,opt,name=exitCode,proto3" json:"exitCode,omitempty"`
Reason string `protobuf:"bytes,5,opt,name=reason,proto3" json:"reason,omitempty"`
Restart int32 `protobuf:"varint,6,opt,name=Restart,proto3" json:"Restart,omitempty"`
Cpu int32 `protobuf:"varint,7,opt,name=Cpu,proto3" json:"Cpu,omitempty"`
Ram int32 `protobuf:"varint,8,opt,name=Ram,proto3" json:"Ram,omitempty"`
Gpu int32 `protobuf:"varint,9,opt,name=Gpu,proto3" json:"Gpu,omitempty"`
// contains filtered or unexported fields
}
func (*Container) Descriptor
deprecated
added in
v1.1.30
func (*Container) GetExitCode ¶ added in v1.1.45
func (*Container) GetRestart ¶ added in v1.1.30
func (*Container) ProtoMessage ¶ added in v1.1.30
func (*Container) ProtoMessage()
func (*Container) ProtoReflect ¶ added in v1.1.30
func (x *Container) ProtoReflect() protoreflect.Message
type EciCache ¶ added in v1.1.71
type EciCache struct {
Id string `protobuf:"bytes,1,opt,name=Id,proto3" json:"Id,omitempty"`
Progress int32 `protobuf:"varint,2,opt,name=progress,proto3" json:"progress,omitempty"`
ErrMessage string `protobuf:"bytes,3,opt,name=errMessage,proto3" json:"errMessage,omitempty"`
// contains filtered or unexported fields
}
func (*EciCache) Descriptor
deprecated
added in
v1.1.71
func (*EciCache) GetErrMessage ¶ added in v1.1.71
func (*EciCache) GetProgress ¶ added in v1.1.71
func (*EciCache) ProtoMessage ¶ added in v1.1.71
func (*EciCache) ProtoMessage()
func (*EciCache) ProtoReflect ¶ added in v1.1.71
func (x *EciCache) ProtoReflect() protoreflect.Message
type EciPod ¶
type EciPod struct {
CustomerId string `protobuf:"bytes,1,opt,name=CustomerId,proto3" json:"CustomerId,omitempty"`
UserId string `protobuf:"bytes,2,opt,name=UserId,proto3" json:"UserId,omitempty"`
VNodeId string `protobuf:"bytes,3,opt,name=VNodeId,proto3" json:"VNodeId,omitempty"`
ContainerGroupName string `protobuf:"bytes,4,opt,name=containerGroupName,proto3" json:"containerGroupName,omitempty"`
Pod *Pod `protobuf:"bytes,5,opt,name=Pod,proto3" json:"Pod,omitempty"`
SpotStrategy string `protobuf:"bytes,6,opt,name=spotStrategy,proto3" json:"spotStrategy,omitempty"`
SpotPrice string `protobuf:"bytes,7,opt,name=spotPrice,proto3" json:"spotPrice,omitempty"`
Runtime string `protobuf:"bytes,8,opt,name=runtime,proto3" json:"runtime,omitempty"`
// contains filtered or unexported fields
}
func (*EciPod) Descriptor
deprecated
func (*EciPod) GetContainerGroupName ¶ added in v1.1.27
func (*EciPod) GetCustomerId ¶
func (*EciPod) GetRuntime ¶ added in v1.1.82
func (*EciPod) GetSpotPrice ¶ added in v1.1.55
func (*EciPod) GetSpotStrategy ¶ added in v1.1.54
func (*EciPod) GetVNodeId ¶
func (*EciPod) ProtoMessage ¶
func (*EciPod) ProtoMessage()
func (*EciPod) ProtoReflect ¶
func (x *EciPod) ProtoReflect() protoreflect.Message
type EciServiceClient ¶
type EciServiceClient interface {
SavePod(ctx context.Context, in *EciPod, opts ...grpc.CallOption) (*SavePodResp, error)
SaveVNode(ctx context.Context, in *EciVNode, opts ...grpc.CallOption) (*SaveVNodeResp, error)
SendUserNotification(ctx context.Context, in *NotifyRequest, opts ...grpc.CallOption) (*NotifyResponse, error)
HasBalance(ctx context.Context, in *BalanceRequest, opts ...grpc.CallOption) (*BalanceResponse, error)
SaveCaches(ctx context.Context, in *EciCache, opts ...grpc.CallOption) (*SaveCacheResponse, error)
}
EciServiceClient is the client API for EciService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewEciServiceClient ¶
func NewEciServiceClient(cc grpc.ClientConnInterface) EciServiceClient
type EciServiceServer ¶
type EciServiceServer interface {
SavePod(context.Context, *EciPod) (*SavePodResp, error)
SaveVNode(context.Context, *EciVNode) (*SaveVNodeResp, error)
SendUserNotification(context.Context, *NotifyRequest) (*NotifyResponse, error)
HasBalance(context.Context, *BalanceRequest) (*BalanceResponse, error)
SaveCaches(context.Context, *EciCache) (*SaveCacheResponse, error)
// contains filtered or unexported methods
}
EciServiceServer is the server API for EciService service. All implementations must embed UnimplementedEciServiceServer for forward compatibility.
type EciVNode ¶ added in v1.1.23
type EciVNode struct {
CustomerId string `protobuf:"bytes,1,opt,name=CustomerId,proto3" json:"CustomerId,omitempty"`
UserId string `protobuf:"bytes,2,opt,name=UserId,proto3" json:"UserId,omitempty"`
VNodeId string `protobuf:"bytes,3,opt,name=VNodeId,proto3" json:"VNodeId,omitempty"`
Ready bool `protobuf:"varint,4,opt,name=Ready,proto3" json:"Ready,omitempty"`
// contains filtered or unexported fields
}
func (*EciVNode) Descriptor
deprecated
added in
v1.1.23
func (*EciVNode) GetCustomerId ¶ added in v1.1.23
func (*EciVNode) GetVNodeId ¶ added in v1.1.23
func (*EciVNode) ProtoMessage ¶ added in v1.1.23
func (*EciVNode) ProtoMessage()
func (*EciVNode) ProtoReflect ¶ added in v1.1.23
func (x *EciVNode) ProtoReflect() protoreflect.Message
type NetworkInfo ¶
type NetworkInfo struct {
Ip string `protobuf:"bytes,1,opt,name=Ip,proto3" json:"Ip,omitempty"`
Vlan string `protobuf:"bytes,2,opt,name=Vlan,proto3" json:"Vlan,omitempty"`
Gateway string `protobuf:"bytes,3,opt,name=Gateway,proto3" json:"Gateway,omitempty"`
// contains filtered or unexported fields
}
func (*NetworkInfo) Descriptor
deprecated
func (*NetworkInfo) Descriptor() ([]byte, []int)
Deprecated: Use NetworkInfo.ProtoReflect.Descriptor instead.
func (*NetworkInfo) GetGateway ¶
func (x *NetworkInfo) GetGateway() string
func (*NetworkInfo) GetIp ¶
func (x *NetworkInfo) GetIp() string
func (*NetworkInfo) GetVlan ¶
func (x *NetworkInfo) GetVlan() string
func (*NetworkInfo) ProtoMessage ¶
func (*NetworkInfo) ProtoMessage()
func (*NetworkInfo) ProtoReflect ¶
func (x *NetworkInfo) ProtoReflect() protoreflect.Message
func (*NetworkInfo) Reset ¶
func (x *NetworkInfo) Reset()
func (*NetworkInfo) String ¶
func (x *NetworkInfo) String() string
type NotifyCode ¶ added in v1.1.56
type NotifyCode int32
const ( NotifyCode_SpotFailed NotifyCode = 0 NotifyCode_SpotCancelDelete NotifyCode = 1 )
func (NotifyCode) Descriptor ¶ added in v1.1.56
func (NotifyCode) Descriptor() protoreflect.EnumDescriptor
func (NotifyCode) Enum ¶ added in v1.1.56
func (x NotifyCode) Enum() *NotifyCode
func (NotifyCode) EnumDescriptor
deprecated
added in
v1.1.56
func (NotifyCode) EnumDescriptor() ([]byte, []int)
Deprecated: Use NotifyCode.Descriptor instead.
func (NotifyCode) Number ¶ added in v1.1.56
func (x NotifyCode) Number() protoreflect.EnumNumber
func (NotifyCode) String ¶ added in v1.1.56
func (x NotifyCode) String() string
func (NotifyCode) Type ¶ added in v1.1.56
func (NotifyCode) Type() protoreflect.EnumType
type NotifyRequest ¶ added in v1.1.53
type NotifyRequest struct {
CustomerId string `protobuf:"bytes,1,opt,name=CustomerId,proto3" json:"CustomerId,omitempty"`
UserId string `protobuf:"bytes,2,opt,name=UserId,proto3" json:"UserId,omitempty"`
Id string `protobuf:"bytes,3,opt,name=Id,proto3" json:"Id,omitempty"`
Code NotifyCode `protobuf:"varint,4,opt,name=code,proto3,enum=pod.NotifyCode" json:"code,omitempty"`
SpotTime int64 `protobuf:"varint,5,opt,name=spotTime,proto3" json:"spotTime,omitempty"`
// contains filtered or unexported fields
}
func (*NotifyRequest) Descriptor
deprecated
added in
v1.1.53
func (*NotifyRequest) Descriptor() ([]byte, []int)
Deprecated: Use NotifyRequest.ProtoReflect.Descriptor instead.
func (*NotifyRequest) GetCode ¶ added in v1.1.56
func (x *NotifyRequest) GetCode() NotifyCode
func (*NotifyRequest) GetCustomerId ¶ added in v1.1.56
func (x *NotifyRequest) GetCustomerId() string
func (*NotifyRequest) GetId ¶ added in v1.1.56
func (x *NotifyRequest) GetId() string
func (*NotifyRequest) GetSpotTime ¶ added in v1.1.75
func (x *NotifyRequest) GetSpotTime() int64
func (*NotifyRequest) GetUserId ¶ added in v1.1.56
func (x *NotifyRequest) GetUserId() string
func (*NotifyRequest) ProtoMessage ¶ added in v1.1.53
func (*NotifyRequest) ProtoMessage()
func (*NotifyRequest) ProtoReflect ¶ added in v1.1.53
func (x *NotifyRequest) ProtoReflect() protoreflect.Message
func (*NotifyRequest) Reset ¶ added in v1.1.53
func (x *NotifyRequest) Reset()
func (*NotifyRequest) String ¶ added in v1.1.53
func (x *NotifyRequest) String() string
type NotifyResponse ¶ added in v1.1.53
type NotifyResponse struct {
// contains filtered or unexported fields
}
func (*NotifyResponse) Descriptor
deprecated
added in
v1.1.53
func (*NotifyResponse) Descriptor() ([]byte, []int)
Deprecated: Use NotifyResponse.ProtoReflect.Descriptor instead.
func (*NotifyResponse) ProtoMessage ¶ added in v1.1.53
func (*NotifyResponse) ProtoMessage()
func (*NotifyResponse) ProtoReflect ¶ added in v1.1.53
func (x *NotifyResponse) ProtoReflect() protoreflect.Message
func (*NotifyResponse) Reset ¶ added in v1.1.53
func (x *NotifyResponse) Reset()
func (*NotifyResponse) String ¶ added in v1.1.53
func (x *NotifyResponse) String() string
type Pod ¶
type Pod struct {
Id string `protobuf:"bytes,1,opt,name=Id,proto3" json:"Id,omitempty"`
UID string `protobuf:"bytes,2,opt,name=UID,proto3" json:"UID,omitempty"`
Name string `protobuf:"bytes,3,opt,name=name,proto3" json:"name,omitempty"`
Namespace string `protobuf:"bytes,4,opt,name=namespace,proto3" json:"namespace,omitempty"`
Status string `protobuf:"bytes,5,opt,name=Status,proto3" json:"Status,omitempty"`
Network *NetworkInfo `protobuf:"bytes,6,opt,name=network,proto3" json:"network,omitempty"`
Cpu int32 `protobuf:"varint,7,opt,name=Cpu,proto3" json:"Cpu,omitempty"`
Ram int32 `protobuf:"varint,8,opt,name=Ram,proto3" json:"Ram,omitempty"`
Gpu int32 `protobuf:"varint,9,opt,name=Gpu,proto3" json:"Gpu,omitempty"`
EphemeralStorage int32 `protobuf:"varint,10,opt,name=ephemeralStorage,proto3" json:"ephemeralStorage,omitempty"`
CpuType string `protobuf:"bytes,11,opt,name=CpuType,proto3" json:"CpuType,omitempty"`
GpuType string `protobuf:"bytes,12,opt,name=GpuType,proto3" json:"GpuType,omitempty"`
Boot bool `protobuf:"varint,13,opt,name=Boot,proto3" json:"Boot,omitempty"`
RestartPolicy string `protobuf:"bytes,14,opt,name=RestartPolicy,proto3" json:"RestartPolicy,omitempty"`
FamilyId string `protobuf:"bytes,15,opt,name=FamilyId,proto3" json:"FamilyId,omitempty"`
Containers []*Container `protobuf:"bytes,16,rep,name=Containers,proto3" json:"Containers,omitempty"`
Code PodStatusCode `protobuf:"varint,17,opt,name=code,proto3,enum=pod.PodStatusCode" json:"code,omitempty"`
// contains filtered or unexported fields
}
func (*Pod) Descriptor
deprecated
func (*Pod) GetCode ¶ added in v1.1.60
func (x *Pod) GetCode() PodStatusCode
func (*Pod) GetContainers ¶ added in v1.1.30
func (*Pod) GetCpuType ¶
func (*Pod) GetEphemeralStorage ¶ added in v1.1.35
func (*Pod) GetFamilyId ¶ added in v1.1.30
func (*Pod) GetGpuType ¶
func (*Pod) GetNamespace ¶ added in v1.1.31
func (*Pod) GetNetwork ¶
func (x *Pod) GetNetwork() *NetworkInfo
func (*Pod) GetRestartPolicy ¶ added in v1.1.20
func (*Pod) ProtoMessage ¶
func (*Pod) ProtoMessage()
func (*Pod) ProtoReflect ¶
func (x *Pod) ProtoReflect() protoreflect.Message
type PodStatusCode ¶ added in v1.1.60
type PodStatusCode int32
const ( PodStatusCode_StatusDefault PodStatusCode = 0 PodStatusCode_StatusSpotFailed PodStatusCode = 1 PodStatusCode_StatusSpotDelayedDelete PodStatusCode = 2 )
func (PodStatusCode) Descriptor ¶ added in v1.1.60
func (PodStatusCode) Descriptor() protoreflect.EnumDescriptor
func (PodStatusCode) Enum ¶ added in v1.1.60
func (x PodStatusCode) Enum() *PodStatusCode
func (PodStatusCode) EnumDescriptor
deprecated
added in
v1.1.60
func (PodStatusCode) EnumDescriptor() ([]byte, []int)
Deprecated: Use PodStatusCode.Descriptor instead.
func (PodStatusCode) Number ¶ added in v1.1.60
func (x PodStatusCode) Number() protoreflect.EnumNumber
func (PodStatusCode) String ¶ added in v1.1.60
func (x PodStatusCode) String() string
func (PodStatusCode) Type ¶ added in v1.1.60
func (PodStatusCode) Type() protoreflect.EnumType
type SaveCacheResponse ¶ added in v1.1.71
type SaveCacheResponse struct {
Code string `protobuf:"bytes,1,opt,name=Code,proto3" json:"Code,omitempty"`
Msg string `protobuf:"bytes,2,opt,name=Msg,proto3" json:"Msg,omitempty"`
// contains filtered or unexported fields
}
func (*SaveCacheResponse) Descriptor
deprecated
added in
v1.1.71
func (*SaveCacheResponse) Descriptor() ([]byte, []int)
Deprecated: Use SaveCacheResponse.ProtoReflect.Descriptor instead.
func (*SaveCacheResponse) GetCode ¶ added in v1.1.71
func (x *SaveCacheResponse) GetCode() string
func (*SaveCacheResponse) GetMsg ¶ added in v1.1.71
func (x *SaveCacheResponse) GetMsg() string
func (*SaveCacheResponse) ProtoMessage ¶ added in v1.1.71
func (*SaveCacheResponse) ProtoMessage()
func (*SaveCacheResponse) ProtoReflect ¶ added in v1.1.71
func (x *SaveCacheResponse) ProtoReflect() protoreflect.Message
func (*SaveCacheResponse) Reset ¶ added in v1.1.71
func (x *SaveCacheResponse) Reset()
func (*SaveCacheResponse) String ¶ added in v1.1.71
func (x *SaveCacheResponse) String() string
type SavePodResp ¶
type SavePodResp struct {
Code string `protobuf:"bytes,1,opt,name=Code,proto3" json:"Code,omitempty"` // v: required
Msg string `protobuf:"bytes,2,opt,name=Msg,proto3" json:"Msg,omitempty"` // v: required
// contains filtered or unexported fields
}
func (*SavePodResp) Descriptor
deprecated
func (*SavePodResp) Descriptor() ([]byte, []int)
Deprecated: Use SavePodResp.ProtoReflect.Descriptor instead.
func (*SavePodResp) GetCode ¶
func (x *SavePodResp) GetCode() string
func (*SavePodResp) GetMsg ¶
func (x *SavePodResp) GetMsg() string
func (*SavePodResp) ProtoMessage ¶
func (*SavePodResp) ProtoMessage()
func (*SavePodResp) ProtoReflect ¶
func (x *SavePodResp) ProtoReflect() protoreflect.Message
func (*SavePodResp) Reset ¶
func (x *SavePodResp) Reset()
func (*SavePodResp) String ¶
func (x *SavePodResp) String() string
type SaveVNodeResp ¶ added in v1.1.23
type SaveVNodeResp struct {
Code string `protobuf:"bytes,1,opt,name=Code,proto3" json:"Code,omitempty"` // v: required
Msg string `protobuf:"bytes,2,opt,name=Msg,proto3" json:"Msg,omitempty"` // v: required
// contains filtered or unexported fields
}
func (*SaveVNodeResp) Descriptor
deprecated
added in
v1.1.23
func (*SaveVNodeResp) Descriptor() ([]byte, []int)
Deprecated: Use SaveVNodeResp.ProtoReflect.Descriptor instead.
func (*SaveVNodeResp) GetCode ¶ added in v1.1.23
func (x *SaveVNodeResp) GetCode() string
func (*SaveVNodeResp) GetMsg ¶ added in v1.1.23
func (x *SaveVNodeResp) GetMsg() string
func (*SaveVNodeResp) ProtoMessage ¶ added in v1.1.23
func (*SaveVNodeResp) ProtoMessage()
func (*SaveVNodeResp) ProtoReflect ¶ added in v1.1.23
func (x *SaveVNodeResp) ProtoReflect() protoreflect.Message
func (*SaveVNodeResp) Reset ¶ added in v1.1.23
func (x *SaveVNodeResp) Reset()
func (*SaveVNodeResp) String ¶ added in v1.1.23
func (x *SaveVNodeResp) String() string
type UnimplementedEciServiceServer ¶
type UnimplementedEciServiceServer struct{}
UnimplementedEciServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedEciServiceServer) HasBalance ¶ added in v1.1.69
func (UnimplementedEciServiceServer) HasBalance(context.Context, *BalanceRequest) (*BalanceResponse, error)
func (UnimplementedEciServiceServer) SaveCaches ¶ added in v1.1.71
func (UnimplementedEciServiceServer) SaveCaches(context.Context, *EciCache) (*SaveCacheResponse, error)
func (UnimplementedEciServiceServer) SavePod ¶
func (UnimplementedEciServiceServer) SavePod(context.Context, *EciPod) (*SavePodResp, error)
func (UnimplementedEciServiceServer) SaveVNode ¶ added in v1.1.23
func (UnimplementedEciServiceServer) SaveVNode(context.Context, *EciVNode) (*SaveVNodeResp, error)
func (UnimplementedEciServiceServer) SendUserNotification ¶ added in v1.1.53
func (UnimplementedEciServiceServer) SendUserNotification(context.Context, *NotifyRequest) (*NotifyResponse, error)
type UnsafeEciServiceServer ¶
type UnsafeEciServiceServer interface {
// contains filtered or unexported methods
}
UnsafeEciServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to EciServiceServer will result in compilation errors.